% tests convergence

clear

for testno=1:2

if testno==1
  p1=0.56;
  p2=0.999;
  N=10;
  A=gallery('pei',N,p1);
  B=gallery('kms',N,p2); 
  % in this case the parameter of convergence os about 100
end

if testno==2
  p1=0.56;
  p2=0.999999;
  N=10;
  A=gallery('pei',N,p1);
  B=gallery('kms',N,p2); 
  % in this case the parameter of convergence os about 10000
end

w=eig(A,B);t=max(w)/min(w);
s=sprintf('The parameter of convergence is %e',t);
disp(s);

 % "exact" geometric mean
 digits(200);
 vA=vpa(A);vB=vpa(B);
 Gv=sharp_vpa(vA,vB,vpa(1/2));G=double(Gv);

 % conditioning exact plus bounds
 [condit b]=mean2_conditioning(A,B);

 % polar decomposition
 [Gp Xp]=mean2_polar_sequence(A,B);

 % sign - entire sequence
 [GS XS YS]=mean2_sign_sequence(A,B);
% [GS XS YS]=mean2_sign_spectral_seq(A,B);

 % averaging - without scaling - entire sequence
 [Ga Xa Ya]=mean2_avera_sequence(A,B);

 % three-term recurrence - entire sequence
 [Gt Xt]=mean2_ttstab_sequence(A,B);

 % gaussian
 for k=1:100
  Xg{k}=mean2_gauss(A,B,k-1);
 end

 % minimax
 for k=1:100
  Xm{k}=mean2_minimax(B,A,k);
 end

if (testno==1 || testno==2)
  N=20; % number of steps;
  for k=1:N
    err_display(1,k)=norm(Xp{k+1}-G)/norm(G);
    err_display(2,k)=norm(YS{k+1}-G)/norm(G);
    err_display(3,k)=norm(Xa{k+1}-G)/norm(G);
    err_display(4,k)=norm(Xt{k+1}-G)/norm(G);
    err_display(5,k)=norm(Xg{k+1}-G)/norm(G);
    err_display(6,k)=norm(Xm{k+1}-G)/norm(G);
  end
  subplot(1,2,testno);
  lw=2;
  cmap=colormap(cool(5));
  semilogy(1:N,max(err_display(3,:),eps/10),'-g*','LineWidth',lw,'Color',cmap(2,:));
  hold on;
  semilogy(1:N,max(err_display(1,:),eps/10),'-o','LineWidth',lw,'Color',cmap(3,:));
  semilogy(1:N,max(err_display(4,:),eps/10),'-r+','LineWidth',lw,'Color',cmap(4,:));

  semilogy(1:N,max(err_display(2,:),eps/10),'-kx','LineWidth',lw,'Color',cmap(5,:));
%  semilogy(1:N,err_display(5,:),'-mv','LineWidth',lw,'Color',cmap(5,:));
% semilogy(1:N,err_display(6,:),'-^','LineWidth',lw,'Color',cmap(6,:));
%  legend('polar','sign','avera','3-term','gauss','minimax');
  legend('avera','polar','tterm','sign');
  axis([0 N+1 1e-16 10]);
end

end